@@ -24,6 +24,7 @@
 
 #include "cc-timezone-map.h"
 #include <math.h>
+#include <string.h>
 #include "tz.h"
 
 G_DEFINE_TYPE (CcTimezoneMap, cc_timezone_map, GTK_TYPE_WIDGET)
@@ -636,17 +637,39 @@ cc_timezone_map_new (void)
   return g_object_new (CC_TYPE_TIMEZONE_MAP, NULL);
 }
 
-void
+static char *
+get_clean_tz (CcTimezoneMap *map,
+	      const char    *tz)
+{
+	char *ret;
+	const char *timezone;
+
+	if (g_str_has_prefix (tz, "right/"))
+		timezone = tz + strlen ("right/");
+	else if (g_str_has_prefix (tz, "posix/"))
+		timezone = tz + strlen ("posix/");
+	else
+		timezone = tz;
+
+	ret = g_hash_table_lookup (map->priv->alias_db, timezone);
+	if (ret == NULL)
+		return g_strdup (timezone);
+	return g_strdup (ret);
+}
+
+gboolean
 cc_timezone_map_set_timezone (CcTimezoneMap *map,
                               const gchar   *timezone)
 {
   GPtrArray *locations;
   guint i;
   char *real_tz;
+  gboolean ret;
 
-  real_tz = g_hash_table_lookup (map->priv->alias_db, timezone);
+  real_tz = get_clean_tz (map, timezone);
 
   locations = tz_get_locations (map->priv->tzdb);
+  ret = FALSE;
 
   for (i = 0; i < locations->len; i++)
     {
@@ -655,11 +678,17 @@ cc_timezone_map_set_timezone (CcTimezoneMap *map,
       if (!g_strcmp0 (loc->zone, real_tz ? real_tz : timezone))
         {
           set_location (map, loc);
+          ret = TRUE;
           break;
         }
     }
 
-  gtk_widget_queue_draw (GTK_WIDGET (map));
+  if (ret)
+    gtk_widget_queue_draw (GTK_WIDGET (map));
+
+  g_free (real_tz);
+
+  return ret;
 }
 
 TzLocation *
