@@ -35,10 +35,16 @@ const gchar *
 panel_device_to_icon_name (NMDevice *device)
 {
         const gchar *value = NULL;
+        NMDeviceState state;
         NMDeviceModemCapabilities caps;
         switch (nm_device_get_device_type (device)) {
         case NM_DEVICE_TYPE_ETHERNET:
-                value = "network-wired";
+                state = nm_device_get_state (device);
+                if (state == NM_DEVICE_STATE_UNAVAILABLE) {
+                        value = "network-wired-disconnected";
+                } else {
+                        value = "network-wired";
+                }
                 break;
         case NM_DEVICE_TYPE_WIFI:
         case NM_DEVICE_TYPE_BT:
@@ -168,10 +174,10 @@ panel_ap_mode_to_localized_string (NM80211Mode mode)
  * panel_device_state_to_localized_string:
  **/
 const gchar *
-panel_device_state_to_localized_string (NMDeviceState type)
+panel_device_state_to_localized_string (NMDeviceType type, NMDeviceState state)
 {
         const gchar *value = NULL;
-        switch (type) {
+        switch (state) {
         case NM_DEVICE_STATE_UNKNOWN:
                 /* TRANSLATORS: device status */
                 value = _("Status unknown");
@@ -182,31 +188,25 @@ panel_device_state_to_localized_string (NMDeviceState type)
                 break;
         case NM_DEVICE_STATE_UNAVAILABLE:
                 /* TRANSLATORS: device status */
-                value = _("Unavailable");
+                if (type == NM_DEVICE_TYPE_ETHERNET)
+                        value = _("Cable unplugged");
+                else
+                        value = _("Unavailable");
                 break;
         case NM_DEVICE_STATE_DISCONNECTED:
                 /* TRANSLATORS: device status */
                 value = _("Disconnected");
                 break;
         case NM_DEVICE_STATE_PREPARE:
-                /* TRANSLATORS: device status */
-                value = _("Preparing connection");
-                break;
         case NM_DEVICE_STATE_CONFIG:
+        case NM_DEVICE_STATE_IP_CONFIG:
+        case NM_DEVICE_STATE_IP_CHECK:
                 /* TRANSLATORS: device status */
-                value = _("Configuring connection");
+                value = _("Connecting");
                 break;
         case NM_DEVICE_STATE_NEED_AUTH:
                 /* TRANSLATORS: device status */
-                value = _("Authenticating");
-                break;
-        case NM_DEVICE_STATE_IP_CONFIG:
-                /* TRANSLATORS: device status */
-                value = _("Getting network address");
-                break;
-        case NM_DEVICE_STATE_IP_CHECK:
-                /* TRANSLATORS: device status */
-                value = _("Checking network address");
+                value = _("Authentication required");
                 break;
         case NM_DEVICE_STATE_ACTIVATED:
                 /* TRANSLATORS: device status */
@@ -218,7 +218,7 @@ panel_device_state_to_localized_string (NMDeviceState type)
                 break;
         case NM_DEVICE_STATE_FAILED:
                 /* TRANSLATORS: device status */
-                value = _("Failed to connect");
+                value = _("Connection failed");
                 break;
         default:
                 /* TRANSLATORS: device status */
@@ -227,3 +227,45 @@ panel_device_state_to_localized_string (NMDeviceState type)
         }
         return value;
 }
+
+/**
+ * panel_vpn_state_to_localized_string:
+ **/
+const gchar *
+panel_vpn_state_to_localized_string (NMVPNConnectionState type)
+{
+        const gchar *value = NULL;
+        switch (type) {
+        case NM_DEVICE_STATE_UNKNOWN:
+                /* TRANSLATORS: VPN status */
+                value = _("Status unknown");
+                break;
+        case NM_VPN_CONNECTION_STATE_PREPARE:
+        case NM_VPN_CONNECTION_STATE_CONNECT:
+        case NM_VPN_CONNECTION_STATE_IP_CONFIG_GET:
+                /* TRANSLATORS: VPN status */
+                value = _("Connecting");
+                break;
+        case NM_VPN_CONNECTION_STATE_NEED_AUTH:
+                /* TRANSLATORS: VPN status */
+                value = _("Authentication required");
+                break;
+        case NM_VPN_CONNECTION_STATE_ACTIVATED:
+                /* TRANSLATORS: VPN status */
+                value = _("Connected");
+                break;
+        case NM_VPN_CONNECTION_STATE_FAILED:
+                /* TRANSLATORS: VPN status */
+                value = _("Connection failed");
+                break;
+        case NM_VPN_CONNECTION_STATE_DISCONNECTED:
+                /* TRANSLATORS: VPN status */
+                value = _("Not connected");
+                break;
+        default:
+                /* TRANSLATORS: VPN status */
+                value = _("Status unknown (missing)");
+                break;
+        }
+        return value;
+}
